pub struct ConversationProcessor { /* private fields */ }Expand description
Processes text (or a list of conversation messages) and deduplicates facts.
Implementations
Sourceimpl ConversationProcessor
impl ConversationProcessor
pub fn new(extractor: Box<dyn FactExtractor>) -> Self
Sourcepub fn process_text(
&self,
text: &str,
source_memory_id: Option<i64>,
) -> Vec<ExtractedFact>
pub fn process_text( &self, text: &str, source_memory_id: Option<i64>, ) -> Vec<ExtractedFact>
Extract facts from a single text, deduplicating by (subject, predicate, object). When duplicates exist the one with the highest confidence is kept.
Sourcepub fn process_conversation(
&self,
messages: &[&str],
source_memory_id: Option<i64>,
) -> Vec<ExtractedFact>
pub fn process_conversation( &self, messages: &[&str], source_memory_id: Option<i64>, ) -> Vec<ExtractedFact>
Extract and deduplicate facts from a slice of messages.