pub struct ProjectContextEngine { /* private fields */ }Expand description
Engine for discovering and ingesting project context
Implementations
Sourceimpl ProjectContextEngine
impl ProjectContextEngine
Sourcepub fn with_config(config: ProjectContextConfig) -> Self
pub fn with_config(config: ProjectContextConfig) -> Self
Create a new engine with custom config
Sourcepub fn scan_directory(&self, path: &Path) -> Result<Vec<DiscoveredFile>>
pub fn scan_directory(&self, path: &Path) -> Result<Vec<DiscoveredFile>>
Scan a directory for instruction files Scan a directory for instruction files Returns (discovered_files, skipped_count)
Sourcepub fn scan_directory_with_stats(
&self,
path: &Path,
) -> Result<(Vec<DiscoveredFile>, usize)>
pub fn scan_directory_with_stats( &self, path: &Path, ) -> Result<(Vec<DiscoveredFile>, usize)>
Scan a directory for instruction files with statistics Returns (discovered_files, skipped_count)
Sourcepub fn parse_file(&self, file: &DiscoveredFile) -> Result<ParsedInstructions>
pub fn parse_file(&self, file: &DiscoveredFile) -> Result<ParsedInstructions>
Parse a discovered file into instructions
Sourcepub fn file_to_memory(&self, file: &DiscoveredFile) -> Memory
pub fn file_to_memory(&self, file: &DiscoveredFile) -> Memory
Convert a discovered file to a parent memory
Sourcepub fn section_to_memory(
&self,
section: &ParsedSection,
file: &DiscoveredFile,
parent_id: i64,
) -> Memory
pub fn section_to_memory( &self, section: &ParsedSection, file: &DiscoveredFile, parent_id: i64, ) -> Memory
Convert a parsed section to a child memory
Sourcepub fn config(&self) -> &ProjectContextConfig
pub fn config(&self) -> &ProjectContextConfig
Get config reference