pub fn create_block(
conn: &Connection,
name: &str,
content: &str,
max_tokens: usize,
) -> Result<MemoryBlock>Expand description
Create a new memory block.
Returns an error if a block with the same name already exists.
pub fn create_block(
conn: &Connection,
name: &str,
content: &str,
max_tokens: usize,
) -> Result<MemoryBlock>Create a new memory block.
Returns an error if a block with the same name already exists.